@@ -20,11 +20,11 @@ impl Plugin for DcmPlugin {
     fn signature(&self) -> Vec<Signature> {
         vec![Signature::build("dcm")
             .desc("Parse Dicom object from file or binary data. Invalid Dicom objects are reported as errors and excluded from the output.")
-            .switch(
-                "silent-errors",
-                "For each input row generate an output row. If Dicom cannot be read, empty row is output. This makes sure that the number of input and output rows is identical. Useful for merging tables.",
-                Some('s')
-            )
+            .named(
+                "error",
+                SyntaxShape::String,
+                "If an error occurs when Dicom object is parsed, the error message will be inserted in this column instead producing an error result.",
+                Some('e'))
             .optional(
                 "column",
                 SyntaxShape::CellPath,
@@ -41,26 +41,22 @@ impl Plugin for DcmPlugin {
         input: &Value,
     ) -> Result<Value, LabeledError> {
         // parse args, nu makes sure the num of args and type is correct
-        let column = call.nth(0);
+        let source_column = call.nth(0);
+        let source_column = if let Some(Value::CellPath { val, span: _ }) = source_column {
+            Some(val)
+        } else {
+            None
+        };
 
-        let source_column = if let Some(Value::CellPath { val, span: _ }) = &column {
-            Some(val.clone())
+        let error_column = call.get_flag_value("error");
+        let error_column = if let Some(Value::String { val, span: _ }) = error_column {
+            Some(val)
         } else {
             None
         };
 
         // run
-        let result = self.run_filter(input, source_column);
-
-        // TODO are silent errors still useful? Figure out how to deal with errors here vs errors in the CellPath list
-        let silent_errors = call.has_flag("silent-errors");
-        match (silent_errors, &result) {
-            // ok or errors should not be silenced, return as is
-            (_, Ok(_)) | (false, Err(_)) => result,
-
-            // found an error and we should silence it
-            (true, Err(_error)) => Ok(Value::Nothing { span: call.head }),
-        }
+        self.run_filter(input, source_column, error_column)
     }
 }
 
@@ -69,6 +65,7 @@ impl DcmPlugin {
         &mut self,
         value: &Value,
         source_column: Option<CellPath>,
+        error_column: Option<String>,
     ) -> Result<Value, LabeledError> {
         // use source column if known
         if let Some(source_column) = source_column {
@@ -76,14 +73,36 @@ impl DcmPlugin {
             let value = value.clone().follow_cell_path(&source_column.members)?;
 
             // AFAIK a list, process_value will handle it
-            self.process_value(&value)
+            self.process_value(&value, &error_column)
         } else {
             // expect a primitive value if column is not known
-            self.process_value(value)
+            self.process_value(value, &error_column)
         }
     }
 
-    fn process_value(&self, value: &Value) -> Result<Value, LabeledError> {
+    fn process_value(
+        &self,
+        value: &Value,
+        error_column: &Option<String>,
+    ) -> Result<Value, LabeledError> {
+        let result = self.process_value_with_normal_error(value, error_column);
+
+        // TODO better value.span().unwrap()
+        match (error_column, &result) {
+            (Some(error_column), Err(err)) => Ok(Value::Record {
+                cols: vec![error_column.to_string()],
+                vals: vec![Value::string(err.msg.to_string(), value.span().unwrap())],
+                span: value.span().unwrap(),
+            }),
+            _ => result,
+        }
+    }
+
+    fn process_value_with_normal_error(
+        &self,
+        value: &Value,
+        error_column: &Option<String>,
+    ) -> Result<Value, LabeledError> {
         match &value {
             Value::String { val, span } => {
                 let obj = read_dcm_file(val).map_err(|e| LabeledError {
@@ -92,7 +111,7 @@ impl DcmPlugin {
                     span: Some(*span),
                 })?;
 
-                self.process_dicom_object(span, obj)
+                self.process_dicom_object(span, obj, error_column)
             }
             Value::Binary { val, span } => {
                 let cursor = Cursor::new(val);
@@ -102,15 +121,14 @@ impl DcmPlugin {
                     span: Some(*span),
                 })?;
 
-                self.process_dicom_object(span, obj)
+                self.process_dicom_object(span, obj, error_column)
             }
             Value::List { vals, span } => {
-                // use either a dicom result or an error for each input element
-                // TODO respect silent-errors flag?
+                // Use either a dicom result or an error for each input element>
                 let result: Vec<Value> = vals
                     .iter()
                     .map(|v| {
-                        self.process_value(v)
+                        self.process_value(v, error_column)
                             .unwrap_or_else(|e| Value::Error { error: e.into() })
                     })
                     .collect();
@@ -132,13 +150,23 @@ impl DcmPlugin {
         &self,
         span: &Span,
         obj: DefaultDicomObject,
+        error_column: &Option<String>,
     ) -> Result<Value, LabeledError> {
         let dcm_dumper = dcm::DicomDump {
             dcm_dictionary: &self.dcm_dictionary,
         };
 
-        // dump both metadata and data into a single table
         let mut index_map = IndexMap::with_capacity(1000);
+
+        // make sure that when --error is used, the column always exists
+        if let Some(error_column) = error_column {
+            index_map.insert(
+                error_column.to_string(),
+                Value::string(String::new(), *span),
+            );
+        }
+
+        // dump both metadata and data into a single table
         make_row_from_dicom_metadata(span, &mut index_map, obj.meta());
         dcm_dumper.make_row_from_dicom_object(span, &mut index_map, &obj);
 
